@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.12"
+__version__ = "1.0.13"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -147,4 +147,5 @@ def deprecated(func, msg=None):
 
 @deprecated
 class Context(Auth):
-    pass
\ No newline at end of file
+    def __init__(self, user, password, api):
+        super(Context, self).__init__(user, password, api)
\ No newline at end of file
